==> wls-plugin-1.3.1-sources.jar: com/xebialabs/deployit/plugin/wls/ci/WlsArtifactMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.ci;

import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;

/**
 * An interface implemented by any mapping that can be targeted to WebLogic middleware.
 */
public interface WlsArtifactMapping {

	/**
	 * Returns the source of the mapping.
	 * 
	 * @return the source
	 */
	NamedDeployableArtifact getSource();

	/**
	 * Returns the target of the mapping.
	 * 
	 * @return the target
	 */
	WlsTarget getTarget();

	/**
	 * Returns the stage-mode for the artifact.
	 * 
	 * @return the stage-mode
	 */
	WlsStageMode getStageMode();

	/**
	 * Returns the staging directory if the stage mode is no-stage.
	 * 
	 * @return the staging directory
	 */
	String getStagingDirectory();

	/**
	 * Returns the deployment plan.
	 * 
	 * @return the deployment plan
	 */
	WlsDeploymentPlan getDeploymentPlan();

	/**
	 * Returns the staging directory for the deployment plan.
	 * 
	 * @return the staging directory for the deployment pla
	 */
	String getDeploymentPlanStagingDirectory();

}

==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/ci/WlsArtifactMapping.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.ci;

import com.xebialabs.deployit.ci.artifact.NamedDeployableArtifact;
import com.xebialabs.deployit.ci.artifact.mapping.PlaceholderFormat;
import com.xebialabs.deployit.ci.mapping.KeyValuePair;

import java.util.List;

/**
 * An interface implemented by any mapping that can be targeted to WebLogic middleware.
 */
public interface WlsArtifactMapping {

	/**
	 * Returns the source of the mapping.
	 * 
	 * @return the source
	 */
	NamedDeployableArtifact getSource();

	/**
	 * Returns the target of the mapping.
	 * 
	 * @return the target
	 */
	WlsTarget getTarget();

	/**
	 * Returns the stage-mode for the artifact.
	 * 
	 * @return the stage-mode
	 */
	WlsStageMode getStageMode();

	/**
	 * Returns the staging directory if the stage mode is no-stage.
	 * 
	 * @return the staging directory
	 */
	String getStagingDirectory();

	/**
	 * Returns the deployment plan.
	 * 
	 * @return the deployment plan
	 */
	WlsDeploymentPlan getDeploymentPlan();

	/**
	 * Returns the staging directory for the deployment plan.
	 * 
	 * @return the staging directory for the deployment plan
	 */
	String getDeploymentPlanStagingDirectory();


	/**
	 * Returns the List of Key Value pair used to be replaced into the artifact.
	 * @return he List of Key Value pair used to be replaced into the artifact.
	 */
	List<KeyValuePair> getKeyValuePairs();

	/**
	 * Returns the placeholder format used in seach & replace into the artifact.
	 * @return the placeholder format used in seach & replace into the artifact.
	 */
	PlaceholderFormat getPlaceholderFormat();

	/**
	 * Strategy of the Deployment.
	 * @return WlsDeploymentStrategy
	 */
	WlsDeploymentStrategy getDeploymentStrategy();

	/**
	 * Set the strategy of the deployment.
	 * @param strategy 
	 */
	void setDeploymentStrategy(WlsDeploymentStrategy strategy);

}
